Documentation
¶
Index ¶
- func DecodeTeeAttestationRequest(attReq []byte) (verification.ITeeVerificationTeeAttestation, error)
- func EncodeTeeAttestationRequest(req *verification.ITeeVerificationTeeAttestation) (hexutil.Bytes, error)
- func ParsePaymentInstruction(data *instruction.DataFixed) (payment.ITeePaymentsPaymentInstructionMessage, error)
- func ParsePubKey(key PublicKey) (*ecdsa.PublicKey, error)
- func ParsePubKeyBytes(key []byte) (*ecdsa.PublicKey, error)
- func ParseVRFInstruction(data *instruction.DataFixed) (vrfstruct.ITeeVrfVrfInstructionMessage, error)
- func PubKeyToBytes(key *ecdsa.PublicKey) []byte
- type Action
- type ActionData
- type ActionInfo
- type ActionResponse
- type ActionResult
- type ActionType
- type ConfigureExtensionIDRequest
- type ConfigureInitialOwnerRequest
- type ConfigureProxyURLRequest
- type DecryptRequest
- type DecryptResponse
- type DirectInstruction
- type InitializePolicyRequest
- type MachineData
- type MultiSignedPolicy
- type OpID
- type ProveRandomnessResponse
- type PublicKey
- type RewardingData
- type SignRequest
- type SignResponse
- type SignedTeeInfoResponse
- type SubmissionTag
- type TeeInfo
- type TeeInfoRequest
- type TeeInfoResponse
- type TeeState
- type UpdatePolicyRequest
- type VoteSequence
- type XRPSignResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecodeTeeAttestationRequest ¶
func DecodeTeeAttestationRequest(attReq []byte) (verification.ITeeVerificationTeeAttestation, error)
DecodeTeeAttestationRequest decodes the attestation request bytes into the strongly typed struct.
func EncodeTeeAttestationRequest ¶
func EncodeTeeAttestationRequest(req *verification.ITeeVerificationTeeAttestation) (hexutil.Bytes, error)
EncodeTeeAttestationRequest serializes the attestation request using the generated struct ABI.
func ParsePaymentInstruction ¶
func ParsePaymentInstruction(data *instruction.DataFixed) (payment.ITeePaymentsPaymentInstructionMessage, error)
ParsePaymentInstruction decodes the payment instruction payload into the XRPL struct representation.
func ParsePubKey ¶
ParsePubKey converts the serialized public key into an ECDSA key.
func ParsePubKeyBytes ¶
ParsePubKeyBytes converts key that consists of concatenated X and Y coordinates into an ECDSA public key. Key is [X||Y] where X and Y are 32 bytes each.
func ParseVRFInstruction ¶
func ParseVRFInstruction(data *instruction.DataFixed) (vrfstruct.ITeeVrfVrfInstructionMessage, error)
ParseVRFInstruction decodes the VRF instruction payload into the shared go-flare-common struct representation.
func PubKeyToBytes ¶
PubKeyToBytes returns the concatenated x and y coordinates of the key.
Types ¶
type ActionData ¶
type ActionData struct {
ID common.Hash `json:"id"`
Type ActionType `json:"type"`
SubmissionTag SubmissionTag `json:"submissionTag"`
Message hexutil.Bytes `json:"message"`
}
type ActionInfo ¶
type ActionInfo struct {
QueueID string `json:"queueId"`
ActionID common.Hash `json:"actionId"`
SubmissionTag SubmissionTag `json:"submissionTag"`
}
type ActionResponse ¶
type ActionResponse struct {
Result ActionResult `json:"result"`
Signature hexutil.Bytes `json:"signature"`
ProxySignature hexutil.Bytes `json:"proxySignature"`
}
type ActionResult ¶
type ActionResult struct {
ID common.Hash `json:"id"`
SubmissionTag SubmissionTag `json:"submissionTag"`
Status uint8 `json:"status"`
Log string `json:"log"`
OPType common.Hash `json:"opType"`
OPCommand common.Hash `json:"opCommand"`
AdditionalResultStatus hexutil.Bytes `json:"additionalResultStatus"`
Version string `json:"version"`
Data hexutil.Bytes `json:"data"`
}
The response received after queuing an action
type ActionType ¶
type ActionType string
const ( Instruction ActionType = "instruction" Direct ActionType = "direct" )
type ConfigureProxyURLRequest ¶
type ConfigureProxyURLRequest struct {
URL *string `json:"url"` // The pointer ensures {} and {"url": ""} unmarshal distinctly.
}
type DecryptRequest ¶
type DecryptRequest struct {
EncryptedMessage []byte `json:"encryptedMessage"`
}
type DecryptResponse ¶
type DecryptResponse struct {
DecryptedMessage []byte `json:"decryptedMessage"`
}
type DirectInstruction ¶
type InitializePolicyRequest ¶
type MachineData ¶
type MultiSignedPolicy ¶
type ProveRandomnessResponse ¶
type PublicKey ¶
func PubKeyToStruct ¶
PubKeyToStruct converts an ECDSA public key into the fixed-size struct form.
type RewardingData ¶
type SignRequest ¶
type SignRequest struct {
Message []byte `json:"message"`
}
type SignResponse ¶
type SignedTeeInfoResponse ¶
type SignedTeeInfoResponse struct {
TeeInfoResponse
ProxySignature hexutil.Bytes `json:"proxySignature"`
}
type SubmissionTag ¶
type SubmissionTag string
const ( // Submission tags for instruction action Threshold SubmissionTag = "threshold" End SubmissionTag = "end" Submit SubmissionTag = "submit" )
type TeeInfo ¶
type TeeInfo struct {
Challenge common.Hash `json:"challenge"`
PublicKey PublicKey `json:"publicKey"`
InitialSigningPolicyID uint32 `json:"initialSigningPolicyId"`
InitialSigningPolicyHash common.Hash `json:"initialSigningPolicyHash"`
LastSigningPolicyID uint32 `json:"lastSigningPolicyId"`
LastSigningPolicyHash common.Hash `json:"lastSigningPolicyHash"`
State TeeState `json:"state"`
TeeTimestamp uint64 `json:"teeTimestamp"`
}
type TeeInfoRequest ¶
type TeeInfoResponse ¶
type UpdatePolicyRequest ¶
type UpdatePolicyRequest struct {
NewPolicy MultiSignedPolicy
PublicKeys []PublicKey
}
type VoteSequence ¶
type VoteSequence struct {
VoteHash common.Hash `json:"voteHash"`
InstructionID common.Hash `json:"instructionId"`
InstructionHash common.Hash `json:"instructionHash"`
RewardEpochID uint32 `json:"rewardEpochId"`
TeeID common.Address `json:"teeId"`
Signatures []hexutil.Bytes `json:"signatures"` // Signatures of the signers and cosigners
AdditionalVariableMessageHashes []common.Hash `json:"additionalVariableMessageHashes"`
Timestamps []uint64 `json:"timestamps"`
}